@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-import polars.polars as plr
+import polars._plr as plr
 from polars.lazyframe.opt_flags import DEFAULT_QUERY_OPT_FLAGS
 
 if TYPE_CHECKING:
@@ -36,6 +36,5 @@ def prepare_cloud_plan(
         If the given LazyFrame cannot be serialized.
     """
     optimizations = optimizations.__copy__()
-    optimizations._pyoptflags.old_streaming = True
     pylf = lf._ldf.with_optimizations(optimizations._pyoptflags)
     return plr.prepare_cloud_plan(pylf)
