@@ -396,6 +396,16 @@ class UInt64(UnsignedIntegerType):
     """64-bit unsigned integer type."""
 
 
+class UInt128(UnsignedIntegerType):
+    """128-bit unsigned integer type.
+
+    .. warning::
+        This functionality is considered **unstable**.
+        It is a work-in-progress feature and may not always work as expected.
+        It may be changed at any point without it being considered a breaking change.
+    """
+
+
 class Float32(FloatType):
     """32-bit floating point type."""
 
@@ -439,6 +449,9 @@ class Decimal(NumericType):
             " It is a work-in-progress feature and may not always work as expected."
         )
 
+        if precision is None:
+            precision = 38
+
         self.precision = precision
         self.scale = scale
 
@@ -760,6 +773,12 @@ class Categories:
     def __eq__(self, other: object) -> bool:
         return isinstance(other, Categories) and self._categories == other._categories
 
+    def __getstate__(self) -> tuple[str, str, PolarsDataType]:
+        return self.name(), self.namespace(), self.physical()
+
+    def __setstate__(self, state: tuple[str, str, PolarsDataType]) -> None:
+        self.__dict__ = Categories(*state).__dict__
+
 
 class Categorical(DataType):
     """
