@@ -281,14 +281,14 @@ def time_(
 
 def duration(
     *,
-    weeks: Expr | str | int | None = None,
-    days: Expr | str | int | None = None,
-    hours: Expr | str | int | None = None,
-    minutes: Expr | str | int | None = None,
-    seconds: Expr | str | int | None = None,
-    milliseconds: Expr | str | int | None = None,
-    microseconds: Expr | str | int | None = None,
-    nanoseconds: Expr | str | int | None = None,
+    weeks: Expr | str | int | float | None = None,
+    days: Expr | str | int | float | None = None,
+    hours: Expr | str | int | float | None = None,
+    minutes: Expr | str | int | float | None = None,
+    seconds: Expr | str | int | float | None = None,
+    milliseconds: Expr | str | int | float | None = None,
+    microseconds: Expr | str | int | float | None = None,
+    nanoseconds: Expr | str | int | float | None = None,
     time_unit: TimeUnit | None = None,
 ) -> Expr:
     """
