@@ -63,6 +63,10 @@ def register_io_source(
         Whether the engine should validate if the batches generated match
         the given schema. It's an implementation error if this isn't
         the case and can lead to bugs that are hard to solve.
+    is_pure
+        Whether the IO source is pure. Repeated occurrences of same IO source in
+        a LazyFrame plan can be de-duplicated during optimization if they are
+        pure.
 
     Returns
     -------
