@@ -5,7 +5,7 @@ import contextlib
 from polars._utils.deprecation import deprecated
 
 with contextlib.suppress(ImportError):  # Module not available when building docs
-    import polars.polars as plr
+    import polars._plr as plr
 
 from typing import TYPE_CHECKING
 
