@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from collections.abc import Sequence
 from typing import TYPE_CHECKING, Any, Callable
 
 from polars import functions as F
@@ -7,7 +8,7 @@ from polars._utils.wrap import wrap_s
 from polars.series.utils import expr_dispatch
 
 if TYPE_CHECKING:
-    from collections.abc import Collection, Sequence
+    from collections.abc import Collection
 
     from polars import Expr, Series
     from polars._plr import PySeries
@@ -922,20 +923,15 @@ class ListNameSpace:
         │ 0   ┆ 1   ┆ null  │
         └─────┴─────┴───────┘
         """
-        s = wrap_s(self._s)
-        return (
-            s.to_frame()
-            .select(
-                F.col(s.name).list.to_struct(
-                    # note: in eager mode, 'upper_bound' is always None, as (unlike
-                    # in lazy mode) there is no need to determine/track the schema.
-                    n_field_strategy,
-                    fields,
-                    _eager=True,
-                )
+        if isinstance(fields, Sequence):
+            s = wrap_s(self._s)
+            return (
+                s.to_frame()
+                .select_seq(F.col(s.name).list.to_struct(fields=fields))
+                .to_series()
             )
-            .to_series()
-        )
+
+        return wrap_s(self._s.list_to_struct(n_field_strategy, fields))
 
     def eval(self, expr: Expr, *, parallel: bool = False) -> Series:
         """
